==> react-native-template-rnbasic-1.0.2.tgz: package/src/navigator/index.js <==
import React, { useEffect } from 'react';
import { useDispatch } from 'react-redux';
import { createStackNavigator } from '@react-navigation/stack';
import { createBottomTabNavigator } from '@react-navigation/bottom-tabs';
import { useFocusEffect } from '@react-navigation/native';
import { Text, Image, View, BackHandler } from 'react-native';
import AsyncStorage from '@react-native-community/async-storage';

import { updateUserInfo } from '../reducers';
import { user } from '../api';

/*****程序页面*****/
// 底部菜单栏
import HomeStack from '../navigator/stack/home';
// 登录
import Login from '../screens/auth/login';
import Forget from '../screens/auth/forget';
// 租客
import Tenant from '../screens/tenant';
import TenantDetail from '../screens/tenant/detail';
import TenantExamine from '../screens/tenant/examine';
// 智能设备
import IotList from '../screens/home/iotlist';
// 修改密码
import ModifyPsd from '../screens/home/modifypsd';
// 报警记录
import AlarmRecord from '../screens/home/alarmrecord';
// 总数据
import TotalData from '../screens/home/totaldata';
// 图片预览
import Preview from '../screens/preview';
/****************/

import { screenOptions } from './config';

const Tab = createBottomTabNavigator();
const Stack = createStackNavigator();

const TabStack = (props) => {
	const dispatch = useDispatch();
	const { navigation } = props;

	function useExitOnBack() {
		useFocusEffect(
			React.useCallback(() => {
				const handleBackPress = () => {
					BackHandler.exitApp();
					return true;
				};
				BackHandler.addEventListener('hardwareBackPress', handleBackPress);
				return () =>
					BackHandler.removeEventListener('hardwareBackPress', handleBackPress);
			}, []),
		);
	}

	useExitOnBack();

	useEffect(() => {
		refreshUserInfo();
	}, []);

	const refreshUserInfo = async () => {
		try {
			let token = await AsyncStorage.getItem('token');
			if (!token) {
				throw new Error('no token');
			}

			let userInfo = await user.getUserInfo();
			dispatch(updateUserInfo(userInfo));
		} catch (e) {
			navigation.reset({
				index: 0,
				routes: [{ name: 'Login' }],
			});
		}
	}

	return (
		<Tab.Navigator tabBarOptions={{ style: { backgroundColor: '#ffffff' } }} screenOptions={({ route }) => ({
			tabBarVisible: false
		})}>
			<Tab.Screen name="Home" component={HomeStack} />
		</Tab.Navigator>
	);
}

const Navigators = () => {
	return (
		<Stack.Navigator initialRouteName='Tab' screenOptions={screenOptions}>
			<Stack.Screen name="Login" component={Login} options={{ headerShown: false }} />
			<Stack.Screen name="Forget" component={Forget} options={{ title: '忘记密码' }} />
			<Stack.Screen name="Tab" component={TabStack} options={{ headerShown: false }} />

			<Stack.Screen name="Tenant" component={Tenant} options={{ title: '租客信息' }} />
			<Stack.Screen name="TenantDetail" component={TenantDetail} options={{ title: '租客信息详情' }} />
			<Stack.Screen name="TenantExamine" component={TenantExamine} options={{ title: '审核租客信息' }} />
			<Stack.Screen name="IotList" component={IotList} />
			<Stack.Screen name="ModifyPsd" component={ModifyPsd} options={{ title: '修改密码' }} />
			<Stack.Screen name="AlarmRecord" component={AlarmRecord} options={{ title: '报警记录' }} />
			<Stack.Screen name="TotalData" component={TotalData} />
			<Stack.Screen name="Preview" component={Preview} options={{ title: '图片预览' }} />
		</Stack.Navigator>
	)
}

export default Navigators;

==> react-native-template-rnbasic-1.0.3.tgz: package/src/navigator/index.js <==
import React, { useEffect } from 'react';
import { useDispatch } from 'react-redux';
import { createStackNavigator } from '@react-navigation/stack';
import { createBottomTabNavigator } from '@react-navigation/bottom-tabs';
import { useFocusEffect } from '@react-navigation/native';
import { Text, Image, View, BackHandler } from 'react-native';

/*****程序页面*****/
// 底部菜单栏
import TestStack from '../navigator/stack/test';
import config from '../tools/config';
/****************/

const Tab = createBottomTabNavigator();
const Stack = createStackNavigator();

const TabStack = (props) => {
	const dispatch = useDispatch();
	const { navigation } = props;

	function useExitOnBack() {
		useFocusEffect(
			React.useCallback(() => {
				const handleBackPress = () => {
					BackHandler.exitApp();
					return true;
				};
				BackHandler.addEventListener('hardwareBackPress', handleBackPress);
				return () =>
					BackHandler.removeEventListener('hardwareBackPress', handleBackPress);
			}, []),
		);
	}

	useExitOnBack();

	useEffect(() => {
	}, []);

	return (
		<Tab.Navigator tabBarOptions={{ style: { backgroundColor: '#ffffff' } }} screenOptions={({ route }) => ({
			tabBarVisible: false
		})}>
			<Tab.Screen name="Test" component={TestStack} />
		</Tab.Navigator>
	);
}

const Navigators = () => {
	return (
		<Stack.Navigator initialRouteName='Tab' screenOptions={config.screenOptions}>
			<Stack.Screen name="Tab" component={TabStack} options={{ headerShown: false }} />
		</Stack.Navigator>
	)
}

export default Navigators;
